function [tab, RowName, ColumnName] = assembletable(tsource, rows, vars, varnames)
% tsource is the source e.g., 'prx' (from pf.prx)
% rows are the fields to extract e.g. {'bio' 'psy'} (empty means all)
% vars are data to extract e.g., {'name' 'nnodes' 'coh'}
% varnames are the names used in the table (empty means use vars)
%
% tab is the table created
% RowName is the names of the rows
% ColName is the names of the columns
%t = assembletable('net',{},...
%{'name' 'type' 'nnodes' 'q' 'r' 'directed' 'nlinks'},...
%{'Name' 'Type' '# nodes' 'q value' 'r value' 'Directed?' '# Links'})
%
% writetable(t,filename,'WriteRowNames',true) ---- creates csv file
% filename and writes the table to it.


global pf
if isempty(rows)
    rows = fieldnames(pf.(tsource)');
end

nr = numel(rows);
nv = numel(vars);

if isempty(varnames) || numel(varnames) ~= nv
    varnames = vars;
end

tab = table('Size', [nr 0]);
tab.Properties.RowNames = rows';

for kv = 1:nv
    dt = emptyclass( pf.(tsource).(rows{1}).(vars{kv}));
    for kr = 1:nr
        d = pf.(tsource).(rows{kr}).(vars{kv});
        if ischar(d)
            d = string(d);
        end
         dt(kr) = d;
    end
    tab = addvars(tab, dt(:));
end

tab.Properties.VariableNames = varnames;
RowName = rows;
ColumnName = varnames;

end