function aveprx(sel)
% averages selected (sel) proximity data sets
global pf

n = numel(sel);

first = pf.prx.(sel{1});
direction = first.distances;
minprx = first.minprx;
maxprx = first.maxprx;
average = first.dis;

if pf.ave.standardize
    average = standardprx(average);
end

if pf.ave.mean
    id = 'Mean';
else
    id = 'Median';
end
id = strcat(id,num2str(n),'_',first.name);

for k = 2:n    
    dat = pf.prx.(sel{k});
    minprx = min(minprx,dat.minprx);
    maxprx = max(maxprx,dat.maxprx);
    if dat.nnodes ~= first.nnodes
        errordlg('Data sets must have the same number of nodes to be averaged.');
        return
    end
    id = strcat(id,'_',dat.name);
    now = dat.dis;
    now((now == Inf)) = dat.maxprx + 1;
    if pf.ave.standardize
        now = standardprx(now);
    end
    
    average(:,:,k) =  now;
end
if pf.ave.mean
    average = mean(average,3);
else
    average = median(average,3);
end
average = setdiagifeq(average,0);
out.contents = 'average';
out.comment = id;
out.file = '-';
out.name = id;
out.distances = direction;
out.nnodes = first.nnodes;
out.nodes = first.nodes;

if pf.ave.standardize
    out.minprx = min(average(:));
    out.maxprx = max(average(:));
else
    out.minprx = minprx;
    out.maxprx = maxprx;
end
out.directed = ~all(all(average == average'));
out.loops = ~all(average(1) == diag(average));

if ~pf.ave.standardize
    average((average < minprx) | (average > maxprx)) = Inf;
end
out.dis = average;

out.coh = coherence(average,out);
[out.stddev, out.ndata] = getstats(out);
out.name = genvarname(strcat(pf.ave.name,'_',num2str(n)),fieldnames(pf.prx));
pf.prx.(out.name) = out;
end

function prx = standardprx(prx)
v = prx(prx ~= Inf);
v = 100 + 20.*zscore(v);
v = round(v);
prx(prx ~= Inf) = v;
end
