function h = drawlink(directed,coord,linktype,linespec)

% coord is 2 by 3, beg end by x y z  ??? for plotarrow 

if directed
    coord = shortenlink(coord,0.04);
    h = plotarrow(...
        coord(1,1),coord(1,2),coord(2,1),coord(2,2),... %x1,y1,x2,y2
        linespec{linktype});
else
    coord = shortenlink(coord,0.02);
    h = plot3(...
        coord(:,1), coord(:,2), coord(:,3),...
        linespec{linktype});
end

end

function c = shortenlink(coord,radius)
% coord is 2 by 3, beg end by x y z [x1, y1, z1; x2, y2, z2]
%radius = .03;  % the amount to shorten

x1 = coord(1,1);
x2 = coord(2,1);
dx = x2 - x1;
y1 = coord(1,2);
y2 = coord(2,2);
dy = y2 - y1;
z1 = coord(1,3);
z2 = coord(2,3);
dz = z2 - z1;
length = sqrt(dx*dx + dy*dy + dz*dz);
if length > 0
    dx = dx / length;
    dy = dy / length;
    dz = dz / length;
end
dx = dx * (length - radius);
dy = dy * (length - radius);
dz = dz * (length - radius);
nx2 = x1 + dx;
ny2 = y1 + dy;
nz2 = z1 + dz;

nx1 = x2 - dx;
ny1 = y2 - dy;
nz1 = z2 - dz;
c = [nx1 ny1 nz1; nx2 ny2 nz2];
end


function handles = plotarrow( x1,y1,x2,y2,linespec)
%
% plotarrow - plots an arrow to the current plot
% format:   handles = plot_arrow( x1,y1,x2,y2)
%
% input:    x1,y1   - starting point
%           x2,y2   - end point
% output:   handles - handles of the graphical elements building the arrow

% =============================================
% constants (can be edited)
% =============================================
global pf
alpha       = 0.05;   % head length
beta        = 0.025;   % head width
if isfield(pf,'pref') && isfield(pf.pref,'arrowhead')
    factor = pf.pref.arrowhead;
else
    factor = 1;
end
factor = factor * .7;
head_length = factor*alpha;
head_width = factor*beta;
% =============================================
% calculate the arrow head coordinates
% =============================================
den         = x2 - x1 + eps;                                % make sure no devision by zero occurs
teta        = atan( (y2-y1)/den ) + pi*(x2<x1) - pi/2;      % angle of arrow
cs          = cos(teta);                                    % rotation matrix
ss          = sin(teta);
R           = [cs -ss;ss cs];
x0          = x2*cs + y2*ss;                                % build head coordinats
y0          = -x2*ss + y2*cs;
coords      = R*[x0 x0+head_width/2 x0-head_width/2; y0 y0-head_length y0-head_length];
% =============================================
% plot arrow  (= line + patch of a triangle)
% =============================================
h1          = plot( [x1,x2],[y1,y2],linespec);
h2          = patch( coords(1,:),coords(2,:),linespec(end));
%hAnnotation = get(h2,'Annotation');
%hLegendEntry = get(hAnnotation','LegendInformation');
%set(hLegendEntry,'IconDisplayStyle','off')                 
                 
% =============================================
% return handles
% =============================================
handles = [h1 h2];
end

