function [props, tbl] = netprops(net)
% computes: center popular mindis degree eccentricity radius diameter of
% the graph

n = net.nnodes;
tbl = table;
nodenums = (1:n)';
in = sum(net.adj)';
out = sum(net.adj,2);
if net.directed
    degree = in + out;
    directed = true;
else
    degree = in;
    directed = false;
end
% degree
props.maxdegree = max(degree);
props.ismaxdegree = net.nodes(degree == props.maxdegree);
% minimum distance
props.mindis = floyd(adj2dis(net.adj),1);
props.eccentricity = max(props.mindis,[],2);
props.meanmin = round(mean(props.mindis,2),4);
props.median = net.nodes(min(props.meanmin) == props.meanmin);
props.radius = min(props.eccentricity);
props.diameter = max(props.eccentricity);
props.center = net.nodes(props.eccentricity == props.radius);

tbl.Node = nodenums;
tbl.Name = net.nodes;
if directed
    tbl.In_Deg = in(:);
    tbl.Out_Deg = out(:);
else
    tbl.Degree = degree(:);
end
tbl.Max_Deg = fillblank(net.nodes,props.ismaxdegree(:));
tbl.Eccentricity = props.eccentricity(:);
tbl.Center = fillblank(net.nodes,props.center(:));
tbl.AveMinDist = props.meanmin(:);
tbl.Median = fillblank(net.nodes,props.median(:));
end

function list = fillblank(nodes, keep)
nn = numel(nodes);
list = repmat(" ",nn,1);
tf = ismember(nodes, keep);
for k = 1:numel(keep)
   s(k) = string(keep{k});  %#ok<AGROW>
end
list(tf) = s;
end

