function  sim = netsim(set1, set2)
global pf

n1 = numel(set1);
n2 = numel(set2);

ci = {'  '};
ci = repmat(ci,n1,n2);
ni = NaN(n1,n2);

sim.name = ci;
sim.net1 = ci;
sim.net2 = ci;
sim.nnodes = ni;
sim.nlinks1 = ni;
sim.nlinks2 = ni;
sim.com = ni;
sim.evcom = ni;
sim.sim = ni;
sim.evsim = ni;
sim.csim = ni;
sim.pprob = ni;
sim.tprob = ni;


for k1 = 1:n1
    for k2 = 1:n2
        net1 = pf.net.(set1{k1});
        net2 = pf.net.(set2{k2});
        c = dosim(net1,net2);
        if ischar(c)
            errordlg(c)
            return
        else
            sim.Net1(k1,k2) = {c.net1};
            sim.Net2(k1,k2) = {c.net2};
            sim.Nlinks1(k1,k2) = c.nlinks1;
            sim.Nlinks2(k1,k2) = c.nlinks2;
            sim.Common(k1,k2) = c.com;
            sim.CommonMinusChance(k1,k2) = c.ccom;
            sim.Similarity(k1,k2) = c.sim;
            sim.SimilarityMinusChance(k1,k2) = c.csim;
            sim.PointProbability(k1,k2) = c.pprob;
            sim.ProbabilitySimOrMore(k1,k2) = c.tprob;
        end
    end
end
sim.Nnodes = c.nnodes(1);
pf.sim = sim;
end

function out = dosim(net1, net2, varargin)
%out = dosim(net1,net2)
%computes network similarity and returns a structure with fields:
%net1 name of net1
%net2 name of net2
%nnodes number of nodes
%nlinks1 number of links in net1
%nlinks2 number of links in net2
%com number of common links (#com)
%evcom expected #com by chance
%com difference of observed and expected common
%sim network similarity  (#com / #unique in both)
%evsim expected similarity by chance
%csim difference of observed and expected similarity
%pointprob point probability - probability of #com by chance
%tailprob tail probability - probability of #com or more by chance

n = net1.nnodes;
if net2.nnodes ~= n
    out.net1 = {net1.pfname};
    out.net2 = {net2.pfname};
    out.nnodes = nan;
    out.nlinks1 = nan;
    out.nlinks2 = nan;
    out.com = nan;
    out.evcom = nan;
    out.ccom = nan;
    out.sim = nan;
    out.evsim = nan;
    out.csim = nan;
    out.pprob = nan;
    out.tprob = nan;
    %     out = [net1.name ' & ' net2.name ...
    %         ' do not have the same number of nodes.  Similarity not computed.'];
    %     return
    return
end
common = net1.adj & net2.adj;
comloops = diag(common);
ncomloops = nnz(comloops);
ncommon = nnz(common);
nl1 = net1.nlinks;
nl2 = net2.nlinks;
npossible = n^2;
if ~net1.loops && ~net2.loops
    npossible = npossible - n;
    npossloops = 0;
else
    npossloops = n;
end
if ~net1.directed && ~net2.directed
    ncommon = ncomloops + (ncommon - ncomloops) / 2;
    npossible = npossloops + (npossible - npossloops) / 2;
end
if net1.directed && ~net2.directed
    nl2 = 2 * nl2;
end
if ~net1.directed && net2.directed
    nl1 = 2 * nl1;
end

sim = ncommon / (nl1 + nl2 - ncommon);

try
    % mincom = max(0,nl1 + nl2 - npossible);
    maxcom = min(nl1, nl2);
    range = 0:maxcom;
    prob = hypergeometric(npossible,nl1,nl2);
    range = double(range);
    evcommon = sum(range .* prob);
    evsim = sum(prob .* (range ./ (nl1 + nl2 - range)));
    pointprob = prob(range == ncommon);
    tailprob = sum(prob(range >= ncommon));
catch
    evcommon = NaN;
    evsim = NaN;
    pointprob = NaN;
    tailprob = NaN;
end

out.net1 = {net1.pfname};
out.net2 = {net2.pfname};
out.nnodes = net1.nnodes;
out.nlinks1 = nl1;
out.nlinks2 = nl2;
out.com = ncommon;
out.evcom = evcommon;
out.ccom = ncommon - evcommon;
out.sim = sim;
out.evsim = evsim;
out.csim = sim - evsim;
out.pprob = pointprob;
out.tprob = tailprob;
end


function out = hypergeometric(p,L1,L2)
% out = hypergeometric(com,p,L1,L2)
% returns the hypergeometric probability density function
% including the probability of 0, 1, 2, ... up to max possible L1 in L2
% p is possible number of links; L1 and L2 are #links in two nets
out = zeros(1,min(L1,L2)+1);
minHits = max(0,L2 - (p - L1));
for c = minHits:min(L1,L2)
    cc = c + 1;
    prob = 1.0;
    for k = 0:min((L1+L2-c)-1,p-1)
        if k < L1
            t1 = L1 - k;
        else
            t1 = p - k;
        end
        if k < L2
            t2 = L2 - k;
        else
            t2 = p - k;
        end
        b1 = p - k;
        if k < c
            b2 = c - k;
        else
            if k < L1
                b2 = L1 - k;
            else
                b2 = L1 + L2 - c - k;
            end
        end
        t1 = double(t1);
        t2 = double(t2);
        b1 = double(b1);
        b2 = double(b2);
        prob = prob * (t1 * t2) / (b1 * b2);
    end
    out(cc) = prob;
end
end

