function node_callback(~,~,~)
% node selection callback
global pf
nodehandle = gcbo; 
nodenum = get(nodehandle,'UserData');
fighandle = gcf;  % figure handle
netname = get(fighandle,'UserData');
if isempty(netname)
    return
end
net = pf.net.(netname);
netname = net.pfname;
seltype = get(fighandle,'SelectionType');

if strcmp(seltype,'open')
    foc = questdlg('Do you want a focus net?','Focus?');
    if strcmp(foc, 'Yes')
        focus(nodenum,netname);
        pf.app.netListBox.Items = fieldnames(pf.net);
    end
    return
end

warning off 

zcoord = net.view.coord(nodenum,3);
axishandle = gca;
p1all = get(axishandle,'CurrentPoint'); % get the original location
p1 = [p1all(1,1), p1all(1,2), zcoord];

ext = get(nodehandle,'Extent');
dragrect(ext);  % move the node

p2all = get(axishandle,'CurrentPoint');
p2 = [p2all(1,1), p2all(1,2), zcoord];

p2 = min(p2,1);
p2 = max(p2,0);
if ~all(p1 == p2) % if node has been moved
    pf.net.(netname).view.coord(nodenum,:) = p2; % store new location
    hold on;
    set(nodehandle,'Position',p2);  % move the node
    for k = 1:net.nlinks  % delete and redraw the links touching the node
        from = net.links(k,1);
        to = net.links(k,2);
        if from == to  % no links to move for loops (loops are borders)
            continue
        end
        if nodenum==from || nodenum==to  % if touching
            if net.directed
                delete(pf.net.(netname).view.linkhandles(k));
                delete(pf.net.(netname).view.arrowhandles(k));
                dh = drawlink(net.directed,...
                     pf.net.(netname).view.coord([from,to],:),...
                     net.linktypes(from,to),pf.linespec);
                pf.net.(netname).view.linkhandles(k) = dh(1);
                pf.net.(netname).view.arrowhandles(k) = dh(2);
            else
                delete(pf.net.(netname).view.linkhandles(k));
                dh = drawlink(net.directed,...
                     pf.net.(netname).view.coord([from,to],:),...
                     net.linktypes(from,to),pf.linespec);
                pf.net.(netname).view.linkhandles(k) = dh(1);             
            end  
            set(dh(1),...
                'UserData',      [from, to, net.dis(from, to)],...
                'ButtonDownFcn', @link_callback);
            pf.net.(netname).linkhandles(k) = dh(1);
            if net.directed
                pf.net.(netname).arrowhandles(k) = dh(2);
            end
        end
    end
end
warning on 
hold off;
pf.lastview = pf.net.(netname).view;
end
