function coord = spring(dis)
% implements the spring algorithm to find x,y coordinates 
% for a layout of graph distances (number of links between nodes) dis

global maxEnode Lside d n_nodes xE yE

d = dis;
n_nodes = length(d);
nodenums = 1:n_nodes;
px = zeros(1,n_nodes);
py = px;
max_prox = max(max(d));
Lside = 2.0/max_prox;
ecc = max(d);
center = nodenums(ecc == min(ecc));

epsilon = 0.005;

d(d==0) = 1; 

% initializes all the data structures for the spring layout

angle_inc = 2 * pi / n_nodes;
angle = 0;
for i = randperm(n_nodes) %Position points onto the rim of a circle with diameter equal to 2
    if ismember(i,center)
        px(i) = 0.5*cos(angle);
        py(i) = 0.5*sin(angle);
    else
        px(i) = cos(angle);
        py(i) = sin(angle);
    end
    angle = angle + angle_inc;
end

for i = 1 : n_nodes %Generate initial values for the xE and yE arrays
    xET = 0.0;
    yET = 0.0;
    for ij = 1 : n_nodes
        if i ~= ij
            dx = px(i) - px(ij);
            dy = py(i) - py(ij);
            denom = kij(i,ij) * (1.0 - lij(i,ij) / sqrt(sqr(dx) + sqr(dy)));
            xET = xET + dx * denom;
            yET = yET + dy * denom;
        end
    end
    xE(i) = xET;
    yE(i) = yET;
end

% energy adjustments
iterations = 0;

while ((iterations < 1000) && (FindMax > epsilon))
    oldPx = px(maxEnode);
    oldPy = py(maxEnode);
    xET = xE(maxEnode);
    yET = yE(maxEnode);
    xE2 = 0.0;
    xyE = 0.0;
    yE2 = 0.0;
    for i = 1 : n_nodes %Generating values to solve the equations:
        if i ~= maxEnode                 %  xE2 * x + xyE * y = - xE }
            dx = px(maxEnode) - px(i);   %  xy2 * x + yE2 * y = - yE }
            dx2 = sqr(dx);        %  for x and y.
            dy = py(maxEnode) - py(i);
            dy2 = sqr(dy);
            tK = kij(maxEnode,i);
            denom = dx2 + dy2;
            denom = lij(maxEnode,i) / (sqrt(denom) * denom);
            xE2 = xE2 + tK * (1.0 - dy2 * denom);
            yE2 = yE2 + tK * (1.0 - dx2 * denom);
            xyE = xyE + tK * dx * dy * denom;
        end
    end
    dy = (xET * xyE - xE2 * yET) / (xE2 * yE2 - xyE * xyE);
    dx = (xET + xyE * dy) / xE2;
    py(maxEnode) = py(maxEnode) + dy;
    px(maxEnode) = px(maxEnode) - dx;
    %  Need to recompute the values for xE and yE  }
    xET = 0.0;
    yET = 0.0;
    for i = 1 : n_nodes
        if i ~= maxEnode
            dx = px(maxEnode) - px(i);
            dy = py(maxEnode) - py(i);
            denom = kij(maxEnode,i) * (1.0 - lij(maxEnode,i) / sqrt(sqr(dx) + sqr(dy)));
            xET = xET + dx * denom;
            yET = yET + dy * denom;
        end
    end
    %             curE = sqrt(sqr(xET) + sqr(yET));
    newPx = px(maxEnode);
    newPy = py(maxEnode);
    xE(maxEnode) = xET;
    yE(maxEnode) = yET;
    
    for i = 1 : n_nodes  %Recompute the xE and yE for each point}
        if i ~= maxEnode
            dx = px(i) - oldPx;
            dy = py(i) - oldPy;
            dx2 = px(i) - newPx;
            dy2 = py(i)  - newPy;
            tK = kij(maxEnode,i);
            denom = 1.0 - lij(maxEnode,i) / sqrt(sqr(dx) + sqr(dy));
            denom2 = 1.0 - lij(maxEnode,i) / sqrt(sqr(dx2) + sqr(dy2));
            xE(i) = xE(i) + tK * (dx2 * denom2 - dx * denom);
            yE(i) = yE(i) + tK * (dy2 * denom2 - dy * denom);
        end
    end
    
    iterations = iterations + 1;
    
end %while


px = px - mean(px);
py = py - mean(py);
coord = [px;py]';
coord = [coord zeros(n_nodes,1)];
end

function maxE = FindMax
global maxEnode n_nodes xE yE
curE = 0.0;
LastMax = 0;
for i = 1 : n_nodes
    
    maxi = sqrt(sqr(xE(i)) + sqr(yE(i)));
    if (maxi > curE) && (i ~= LastMax)
        curE = maxi;
        maxEnode = i;
    end
end
maxE = curE;
end

function l = lij(i,j)
global Lside d
if j < i
    l = Lside*d(i,j);
else
    l = Lside*d(j,i);
end
end

function k = kij(i,j)
global d
if j < i
    k = 1.0/sqr(d(i,j));
else
    k = 1.0/sqr(d(j,i));
end
end

function x2 = sqr(x)
x2 = x*x;
end

